==> python-absl_0.12.0.orig.tar.gz: abseil-py-pypi-v0.12.0/absl/testing/tests/absltest_filtering_test_helper.py <==
# Copyright 2017 The Abseil Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""A helper test program for absltest_filtering_test."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import sys

from absl.testing import absltest


class ClassA(absltest.TestCase):
  """Helper test case A for absltest_filtering_test."""

  def testA(self):
    sys.stderr.write('\nclass A test A\n')

  def testB(self):
    sys.stderr.write('\nclass A test B\n')

  def testC(self):
    sys.stderr.write('\nclass A test C\n')


class ClassB(absltest.TestCase):
  """Helper test case B for absltest_filtering_test."""

  def testA(self):
    sys.stderr.write('\nclass B test A\n')

  def testB(self):
    sys.stderr.write('\nclass B test B\n')

  def testC(self):
    sys.stderr.write('\nclass B test C\n')

  def testD(self):
    sys.stderr.write('\nclass B test D\n')

  def testE(self):
    sys.stderr.write('\nclass B test E\n')
    self.fail('Force failure')


if __name__ == '__main__':
  absltest.main()

==> python-absl_0.15.0.orig.tar.gz: abseil-py-pypi-v0.15.0/absl/testing/tests/absltest_filtering_test_helper.py <==
# Copyright 2017 The Abseil Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""A helper test program for absltest_filtering_test."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import os
import sys

from absl import app
from absl.testing import absltest
from absl.testing import parameterized


class ClassA(absltest.TestCase):
  """Helper test case A for absltest_filtering_test."""

  def testA(self):
    sys.stderr.write('\nclass A test A\n')

  def testB(self):
    sys.stderr.write('\nclass A test B\n')

  def testC(self):
    sys.stderr.write('\nclass A test C\n')


class ClassB(absltest.TestCase):
  """Helper test case B for absltest_filtering_test."""

  def testA(self):
    sys.stderr.write('\nclass B test A\n')

  def testB(self):
    sys.stderr.write('\nclass B test B\n')

  def testC(self):
    sys.stderr.write('\nclass B test C\n')

  def testD(self):
    sys.stderr.write('\nclass B test D\n')

  def testE(self):
    sys.stderr.write('\nclass B test E\n')
    self.fail('Force failure')


class ParameterizedTest(parameterized.TestCase):
  """Helper parameterized test case for absltest_filtering_test."""

  @parameterized.parameters([1, 2])
  def test_unnamed(self, value):
    sys.stderr.write('\nparameterized unnamed %s' % value)

  @parameterized.named_parameters(
      ('test1', 1),
      ('test2', 2),
  )
  def test_named(self, value):
    sys.stderr.write('\nparameterized named %s' % value)


def main(argv):
  absltest.main(argv=argv)


if __name__ == '__main__':
  if os.environ['USE_APP_RUN'] == '1':
    app.run(main)
  else:
    absltest.main()
